@@ -10,15 +10,15 @@ __all__ = (
 )
 
 from collections import defaultdict
-from collections.abc import Mapping
+from collections.abc import Mapping, MutableSet, Set
 from functools import partial
-from itertools import chain, filterfalse
+from itertools import chain, filterfalse, islice
 import operator
 
-from .klass import get, contains, steal_docs, _sentinel
+from .klass import get, contains, steal_docs, sentinel
 
 
-class DictMixin(object):
+class DictMixin:
     """
     new style class replacement for :py:func:`UserDict.DictMixin`
     designed around iter* methods rather then forcing lists as DictMixin does
@@ -95,14 +95,14 @@ class DictMixin(object):
         return not self.__eq__(other)
 
     @steal_docs(dict)
-    def pop(self, key, default=_sentinel):
+    def pop(self, key, default=sentinel):
         if not self.__externally_mutable__:
             raise AttributeError(self, "pop")
         try:
             val = self[key]
             del self[key]
         except KeyError:
-            if default is not _sentinel:
+            if default is not sentinel:
                 return default
             raise
         return val
@@ -331,10 +331,13 @@ class ImmutableDict(Mapping):
         return self._dict[key]
 
     def __iter__(self):
-        return iter(self._dict.keys())
+        return iter(self._dict)
+
+    def __reversed__(self):
+        return reversed(self._dict)
 
     def __len__(self):
-        return len(list(self._dict.keys()))
+        return len(self._dict)
 
     def __repr__(self):
         return str(self._dict)
@@ -346,7 +349,91 @@ class ImmutableDict(Mapping):
         return hash(tuple(sorted(self._dict.items(), key=operator.itemgetter(0))))
 
 
-class IndeterminantDict(object):
+class OrderedFrozenSet(Set):
+    """Ordered, immutable set using guaranteed insertion order dicts in py3.6 onwards."""
+
+    def __init__(self, iterable=()):
+        try:
+            self._dict = ImmutableDict({x: None for x in iterable})
+        except TypeError as e:
+            raise TypeError('not iterable') from e
+
+    def __contains__(self, key):
+        return key in self._dict
+
+    def __iter__(self):
+        return iter(self._dict)
+
+    def __getitem__(self, key):
+        try:
+            return next(islice(self._dict, key, None))
+        except StopIteration:
+            raise IndexError('index out of range')
+
+    def __reversed__(self):
+        return reversed(self._dict)
+
+    def __len__(self):
+        return len(self._dict)
+
+    def __eq__(self, other):
+        return set(self._dict) == other
+
+    def __str__(self):
+        elements_str = ', '.join(map(repr, self._dict))
+        return f'{{{elements_str}}}'
+
+    def __repr__(self):
+        return self.__str__()
+
+    def __hash__(self):
+        return hash(self._dict)
+
+    def intersection(self, other):
+        return self.__class__(self._dict.keys() & other)
+
+    def union(self, other):
+        return self.__class__(self._dict.keys() | other)
+
+    def difference(self, other):
+        return self.__class__(self._dict.keys() - other)
+
+    def symmetric_difference(self, other):
+        return self.__class__(self._dict.keys() ^ other)
+
+
+class OrderedSet(OrderedFrozenSet, MutableSet):
+    """Ordered, mutable set using guaranteed insertion order dicts in py3.6 onwards."""
+
+    def __init__(self, iterable=()):
+        try:
+            self._dict = {x: None for x in iterable}
+        except TypeError as e:
+            raise TypeError('not iterable') from e
+
+    def add(self, value):
+        self._dict[value] = None
+
+    def discard(self, value):
+        try:
+            del self._dict[value]
+        except KeyError:
+            pass
+
+    def remove(self, value):
+        del self._dict[value]
+
+    def clear(self):
+        self._dict = {}
+
+    def update(self, iterable):
+        self._dict.update((x, None) for x in iterable)
+
+    def __hash__(self):
+        raise TypeError(f'unhashable type: {self.__class__.__name__!r}')
+
+
+class IndeterminantDict:
     """A wrapped dict with constant defaults, and a function for other keys.
 
     The primary use for this class is to make a JIT loaded mapping- for instance, a
@@ -605,7 +692,7 @@ class ProxiedAttrs(DictMixin):
 
     Example usage:
 
-    >>> class foo(object):
+    >>> class foo:
     ...     pass
     >>> obj = foo()
     >>> obj.x, obj.y = 1, 2
@@ -665,7 +752,7 @@ def native_attr_contains(self, key):
 # python issue 7604; depending on the python version, delattr'ing an empty slot
 # doesn't throw AttributeError; we vary our implementation for efficiency
 # dependent on a onetime runtime test of that.
-class foo(object):
+class foo:
     __slots__ = ("slot",)
 
 # track which is required since if we can use extensions, we'll have
@@ -705,8 +792,8 @@ def native_attr_pop(self, key, *a):
     l = len(a)
     if l > 1:
         raise TypeError("pop accepts 1 or 2 args only")
-    o = getattr(self, key, _sentinel)
-    if o is not _sentinel:
+    o = getattr(self, key, sentinel)
+    if o is not sentinel:
         object.__delattr__(self, key)
     elif l:
         o = a[0]
