@@ -48,7 +48,7 @@ def mk_named_tempfile(*args, **kwds):
     return io.TextIOWrapper(tmp_f)
 
 
-class PythonNamespaceWalker(object):
+class PythonNamespaceWalker:
 
     ignore_all_import_failures = False
 
@@ -56,7 +56,7 @@ class PythonNamespaceWalker(object):
 
     # This is for py3.2/PEP3149; dso's now have the interp + major/minor embedded
     # in the name.
-    # TODO: Update this for pypy's naming, and jythons.
+    # TODO: update this for pypy's naming
     abi_target = 'cpython-%i%i' % tuple(sys.version_info[:2])
 
     module_blacklist = frozenset([
@@ -178,7 +178,7 @@ class TargetedNamespaceWalker(PythonNamespaceWalker):
         for _mod in self.walk_namespace(namespace):
             pass
 
-class _classWalker(object):
+class _classWalker:
 
     cls_blacklist = frozenset()
 
